# coding: utf-8

"""
    Curia Platform API

    These are the docs for the curia platform API. To test, generate an authorization token first.  # noqa: E501

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import curia.api.swagger_client
from curia.api.swagger_client.api.platform_api import PlatformApi  # noqa: E501
from curia.api.swagger_client.rest import ApiException


class TestPlatformApi(unittest.TestCase):
    """PlatformApi unit test stubs"""

    def setUp(self):
        self.api = PlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_many_base_dataset_controller_dataset(self):
        """Test case for create_many_base_dataset_controller_dataset

        Create many Dataset  # noqa: E501
        """
        pass

    def test_create_many_base_environment_controller_environment(self):
        """Test case for create_many_base_environment_controller_environment

        Create many Environment  # noqa: E501
        """
        pass

    def test_create_many_base_intervention_controller_intervention(self):
        """Test case for create_many_base_intervention_controller_intervention

        Create many Intervention  # noqa: E501
        """
        pass

    def test_create_many_base_model_controller_model(self):
        """Test case for create_many_base_model_controller_model

        Create many Model  # noqa: E501
        """
        pass

    def test_create_many_base_model_dataset_controller_model_dataset(self):
        """Test case for create_many_base_model_dataset_controller_model_dataset

        Create many ModelDataset  # noqa: E501
        """
        pass

    def test_create_many_base_model_endpoint_controller_model_endpoint(self):
        """Test case for create_many_base_model_endpoint_controller_model_endpoint

        Create many ModelEndpoint  # noqa: E501
        """
        pass

    def test_create_many_base_model_job_controller_model_job(self):
        """Test case for create_many_base_model_job_controller_model_job

        Create many ModelJob  # noqa: E501
        """
        pass

    def test_create_many_base_organization_setting_controller_organization_setting(self):
        """Test case for create_many_base_organization_setting_controller_organization_setting

        Create many OrganizationSetting  # noqa: E501
        """
        pass

    def test_create_many_base_organizations_controller_organization(self):
        """Test case for create_many_base_organizations_controller_organization

        Create many Organization  # noqa: E501
        """
        pass

    def test_create_many_base_project_controller_project(self):
        """Test case for create_many_base_project_controller_project

        Create many Project  # noqa: E501
        """
        pass

    def test_create_many_base_project_member_controller_project_member(self):
        """Test case for create_many_base_project_member_controller_project_member

        Create many ProjectMember  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for create_many_base_timeline_code_filter_controller_timeline_code_filter

        Create many TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_controller_timeline(self):
        """Test case for create_many_base_timeline_controller_timeline

        Create many Timeline  # noqa: E501
        """
        pass

    def test_create_many_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for create_many_base_timeline_feature_filter_controller_timeline_feature_filter

        Create many TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_create_many_base_user_favorite_controller_user_favorite(self):
        """Test case for create_many_base_user_favorite_controller_user_favorite

        Create many UserFavorite  # noqa: E501
        """
        pass

    def test_create_one_base_dataset_controller_dataset(self):
        """Test case for create_one_base_dataset_controller_dataset

        Create one Dataset  # noqa: E501
        """
        pass

    def test_create_one_base_environment_controller_environment(self):
        """Test case for create_one_base_environment_controller_environment

        Create one Environment  # noqa: E501
        """
        pass

    def test_create_one_base_intervention_controller_intervention(self):
        """Test case for create_one_base_intervention_controller_intervention

        Create one Intervention  # noqa: E501
        """
        pass

    def test_create_one_base_model_controller_model(self):
        """Test case for create_one_base_model_controller_model

        Create one Model  # noqa: E501
        """
        pass

    def test_create_one_base_model_dataset_controller_model_dataset(self):
        """Test case for create_one_base_model_dataset_controller_model_dataset

        Create one ModelDataset  # noqa: E501
        """
        pass

    def test_create_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for create_one_base_model_endpoint_controller_model_endpoint

        Create one ModelEndpoint  # noqa: E501
        """
        pass

    def test_create_one_base_model_job_controller_model_job(self):
        """Test case for create_one_base_model_job_controller_model_job

        Create one ModelJob  # noqa: E501
        """
        pass

    def test_create_one_base_organization_setting_controller_organization_setting(self):
        """Test case for create_one_base_organization_setting_controller_organization_setting

        Create one OrganizationSetting  # noqa: E501
        """
        pass

    def test_create_one_base_organizations_controller_organization(self):
        """Test case for create_one_base_organizations_controller_organization

        Create one Organization  # noqa: E501
        """
        pass

    def test_create_one_base_project_controller_project(self):
        """Test case for create_one_base_project_controller_project

        Create one Project  # noqa: E501
        """
        pass

    def test_create_one_base_project_member_controller_project_member(self):
        """Test case for create_one_base_project_member_controller_project_member

        Create one ProjectMember  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for create_one_base_timeline_code_filter_controller_timeline_code_filter

        Create one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_controller_timeline(self):
        """Test case for create_one_base_timeline_controller_timeline

        Create one Timeline  # noqa: E501
        """
        pass

    def test_create_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for create_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Create one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_create_one_base_user_favorite_controller_user_favorite(self):
        """Test case for create_one_base_user_favorite_controller_user_favorite

        Create one UserFavorite  # noqa: E501
        """
        pass

    def test_dataset_controller_get_summary(self):
        """Test case for dataset_controller_get_summary

        """
        pass

    def test_dataset_controller_upload(self):
        """Test case for dataset_controller_upload

        """
        pass

    def test_delete_one_base_dataset_controller_dataset(self):
        """Test case for delete_one_base_dataset_controller_dataset

        Delete one Dataset  # noqa: E501
        """
        pass

    def test_delete_one_base_environment_controller_environment(self):
        """Test case for delete_one_base_environment_controller_environment

        Delete one Environment  # noqa: E501
        """
        pass

    def test_delete_one_base_intervention_controller_intervention(self):
        """Test case for delete_one_base_intervention_controller_intervention

        Delete one Intervention  # noqa: E501
        """
        pass

    def test_delete_one_base_model_controller_model(self):
        """Test case for delete_one_base_model_controller_model

        Delete one Model  # noqa: E501
        """
        pass

    def test_delete_one_base_model_dataset_controller_model_dataset(self):
        """Test case for delete_one_base_model_dataset_controller_model_dataset

        Delete one ModelDataset  # noqa: E501
        """
        pass

    def test_delete_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for delete_one_base_model_endpoint_controller_model_endpoint

        Delete one ModelEndpoint  # noqa: E501
        """
        pass

    def test_delete_one_base_model_job_controller_model_job(self):
        """Test case for delete_one_base_model_job_controller_model_job

        Delete one ModelJob  # noqa: E501
        """
        pass

    def test_delete_one_base_organization_setting_controller_organization_setting(self):
        """Test case for delete_one_base_organization_setting_controller_organization_setting

        Delete one OrganizationSetting  # noqa: E501
        """
        pass

    def test_delete_one_base_organizations_controller_organization(self):
        """Test case for delete_one_base_organizations_controller_organization

        Delete one Organization  # noqa: E501
        """
        pass

    def test_delete_one_base_project_controller_project(self):
        """Test case for delete_one_base_project_controller_project

        Delete one Project  # noqa: E501
        """
        pass

    def test_delete_one_base_project_member_controller_project_member(self):
        """Test case for delete_one_base_project_member_controller_project_member

        Delete one ProjectMember  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for delete_one_base_timeline_code_filter_controller_timeline_code_filter

        Delete one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_controller_timeline(self):
        """Test case for delete_one_base_timeline_controller_timeline

        Delete one Timeline  # noqa: E501
        """
        pass

    def test_delete_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for delete_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Delete one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_delete_one_base_user_favorite_controller_user_favorite(self):
        """Test case for delete_one_base_user_favorite_controller_user_favorite

        Delete one UserFavorite  # noqa: E501
        """
        pass

    def test_environment_controller_start(self):
        """Test case for environment_controller_start

        """
        pass

    def test_environment_controller_status(self):
        """Test case for environment_controller_status

        """
        pass

    def test_environment_controller_stop(self):
        """Test case for environment_controller_stop

        """
        pass

    def test_get_many_base_dataset_controller_dataset(self):
        """Test case for get_many_base_dataset_controller_dataset

        Retrieve many Dataset  # noqa: E501
        """
        pass

    def test_get_many_base_environment_controller_environment(self):
        """Test case for get_many_base_environment_controller_environment

        Retrieve many Environment  # noqa: E501
        """
        pass

    def test_get_many_base_intervention_controller_intervention(self):
        """Test case for get_many_base_intervention_controller_intervention

        Retrieve many Intervention  # noqa: E501
        """
        pass

    def test_get_many_base_model_controller_model(self):
        """Test case for get_many_base_model_controller_model

        Retrieve many Model  # noqa: E501
        """
        pass

    def test_get_many_base_model_dataset_controller_model_dataset(self):
        """Test case for get_many_base_model_dataset_controller_model_dataset

        Retrieve many ModelDataset  # noqa: E501
        """
        pass

    def test_get_many_base_model_endpoint_controller_model_endpoint(self):
        """Test case for get_many_base_model_endpoint_controller_model_endpoint

        Retrieve many ModelEndpoint  # noqa: E501
        """
        pass

    def test_get_many_base_model_job_controller_model_job(self):
        """Test case for get_many_base_model_job_controller_model_job

        Retrieve many ModelJob  # noqa: E501
        """
        pass

    def test_get_many_base_model_job_event_controller_model_job_event(self):
        """Test case for get_many_base_model_job_event_controller_model_job_event

        Retrieve many ModelJobEvent  # noqa: E501
        """
        pass

    def test_get_many_base_organization_setting_controller_organization_setting(self):
        """Test case for get_many_base_organization_setting_controller_organization_setting

        Retrieve many OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_many_base_organizations_controller_organization(self):
        """Test case for get_many_base_organizations_controller_organization

        Retrieve many Organization  # noqa: E501
        """
        pass

    def test_get_many_base_project_controller_project(self):
        """Test case for get_many_base_project_controller_project

        Retrieve many Project  # noqa: E501
        """
        pass

    def test_get_many_base_project_member_controller_project_member(self):
        """Test case for get_many_base_project_member_controller_project_member

        Retrieve many ProjectMember  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for get_many_base_timeline_code_filter_controller_timeline_code_filter

        Retrieve many TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_controller_timeline(self):
        """Test case for get_many_base_timeline_controller_timeline

        Retrieve many Timeline  # noqa: E501
        """
        pass

    def test_get_many_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for get_many_base_timeline_feature_filter_controller_timeline_feature_filter

        Retrieve many TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_get_many_base_user_favorite_controller_user_favorite(self):
        """Test case for get_many_base_user_favorite_controller_user_favorite

        Retrieve many UserFavorite  # noqa: E501
        """
        pass

    def test_get_one_base_dataset_controller_dataset(self):
        """Test case for get_one_base_dataset_controller_dataset

        Retrieve one Dataset  # noqa: E501
        """
        pass

    def test_get_one_base_environment_controller_environment(self):
        """Test case for get_one_base_environment_controller_environment

        Retrieve one Environment  # noqa: E501
        """
        pass

    def test_get_one_base_intervention_controller_intervention(self):
        """Test case for get_one_base_intervention_controller_intervention

        Retrieve one Intervention  # noqa: E501
        """
        pass

    def test_get_one_base_model_controller_model(self):
        """Test case for get_one_base_model_controller_model

        Retrieve one Model  # noqa: E501
        """
        pass

    def test_get_one_base_model_dataset_controller_model_dataset(self):
        """Test case for get_one_base_model_dataset_controller_model_dataset

        Retrieve one ModelDataset  # noqa: E501
        """
        pass

    def test_get_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for get_one_base_model_endpoint_controller_model_endpoint

        Retrieve one ModelEndpoint  # noqa: E501
        """
        pass

    def test_get_one_base_model_job_controller_model_job(self):
        """Test case for get_one_base_model_job_controller_model_job

        Retrieve one ModelJob  # noqa: E501
        """
        pass

    def test_get_one_base_model_job_event_controller_model_job_event(self):
        """Test case for get_one_base_model_job_event_controller_model_job_event

        Retrieve one ModelJobEvent  # noqa: E501
        """
        pass

    def test_get_one_base_organization_setting_controller_organization_setting(self):
        """Test case for get_one_base_organization_setting_controller_organization_setting

        Retrieve one OrganizationSetting  # noqa: E501
        """
        pass

    def test_get_one_base_organizations_controller_organization(self):
        """Test case for get_one_base_organizations_controller_organization

        Retrieve one Organization  # noqa: E501
        """
        pass

    def test_get_one_base_project_controller_project(self):
        """Test case for get_one_base_project_controller_project

        Retrieve one Project  # noqa: E501
        """
        pass

    def test_get_one_base_project_member_controller_project_member(self):
        """Test case for get_one_base_project_member_controller_project_member

        Retrieve one ProjectMember  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for get_one_base_timeline_code_filter_controller_timeline_code_filter

        Retrieve one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_controller_timeline(self):
        """Test case for get_one_base_timeline_controller_timeline

        Retrieve one Timeline  # noqa: E501
        """
        pass

    def test_get_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for get_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Retrieve one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_get_one_base_user_favorite_controller_user_favorite(self):
        """Test case for get_one_base_user_favorite_controller_user_favorite

        Retrieve one UserFavorite  # noqa: E501
        """
        pass

    def test_intervention_controller_get_upload_url(self):
        """Test case for intervention_controller_get_upload_url

        """
        pass

    def test_model_controller_clone_model(self):
        """Test case for model_controller_clone_model

        """
        pass

    def test_model_endpoint_controller_invoke(self):
        """Test case for model_endpoint_controller_invoke

        """
        pass

    def test_model_endpoint_controller_start(self):
        """Test case for model_endpoint_controller_start

        """
        pass

    def test_model_endpoint_controller_status(self):
        """Test case for model_endpoint_controller_status

        """
        pass

    def test_model_endpoint_controller_stop(self):
        """Test case for model_endpoint_controller_stop

        """
        pass

    def test_model_job_controller_get_prediction_output_data(self):
        """Test case for model_job_controller_get_prediction_output_data

        """
        pass

    def test_model_job_controller_get_predictions_url(self):
        """Test case for model_job_controller_get_predictions_url

        """
        pass

    def test_model_job_controller_get_training_output_data(self):
        """Test case for model_job_controller_get_training_output_data

        """
        pass

    def test_model_job_controller_start(self):
        """Test case for model_job_controller_start

        """
        pass

    def test_model_job_controller_status(self):
        """Test case for model_job_controller_status

        """
        pass

    def test_model_job_controller_stop(self):
        """Test case for model_job_controller_stop

        """
        pass

    def test_project_controller_get_all_project_children(self):
        """Test case for project_controller_get_all_project_children

        """
        pass

    def test_project_controller_get_all_project_parents(self):
        """Test case for project_controller_get_all_project_parents

        """
        pass

    def test_replace_one_base_dataset_controller_dataset(self):
        """Test case for replace_one_base_dataset_controller_dataset

        Replace one Dataset  # noqa: E501
        """
        pass

    def test_replace_one_base_environment_controller_environment(self):
        """Test case for replace_one_base_environment_controller_environment

        Replace one Environment  # noqa: E501
        """
        pass

    def test_replace_one_base_intervention_controller_intervention(self):
        """Test case for replace_one_base_intervention_controller_intervention

        Replace one Intervention  # noqa: E501
        """
        pass

    def test_replace_one_base_model_controller_model(self):
        """Test case for replace_one_base_model_controller_model

        Replace one Model  # noqa: E501
        """
        pass

    def test_replace_one_base_model_dataset_controller_model_dataset(self):
        """Test case for replace_one_base_model_dataset_controller_model_dataset

        Replace one ModelDataset  # noqa: E501
        """
        pass

    def test_replace_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for replace_one_base_model_endpoint_controller_model_endpoint

        Replace one ModelEndpoint  # noqa: E501
        """
        pass

    def test_replace_one_base_model_job_controller_model_job(self):
        """Test case for replace_one_base_model_job_controller_model_job

        Replace one ModelJob  # noqa: E501
        """
        pass

    def test_replace_one_base_organization_setting_controller_organization_setting(self):
        """Test case for replace_one_base_organization_setting_controller_organization_setting

        Replace one OrganizationSetting  # noqa: E501
        """
        pass

    def test_replace_one_base_organizations_controller_organization(self):
        """Test case for replace_one_base_organizations_controller_organization

        Replace one Organization  # noqa: E501
        """
        pass

    def test_replace_one_base_project_controller_project(self):
        """Test case for replace_one_base_project_controller_project

        Replace one Project  # noqa: E501
        """
        pass

    def test_replace_one_base_project_member_controller_project_member(self):
        """Test case for replace_one_base_project_member_controller_project_member

        Replace one ProjectMember  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for replace_one_base_timeline_code_filter_controller_timeline_code_filter

        Replace one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_controller_timeline(self):
        """Test case for replace_one_base_timeline_controller_timeline

        Replace one Timeline  # noqa: E501
        """
        pass

    def test_replace_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for replace_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Replace one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_replace_one_base_user_favorite_controller_user_favorite(self):
        """Test case for replace_one_base_user_favorite_controller_user_favorite

        Replace one UserFavorite  # noqa: E501
        """
        pass

    def test_timeline_controller_build_timeline(self):
        """Test case for timeline_controller_build_timeline

        """
        pass

    def test_timeline_controller_clone_timeline(self):
        """Test case for timeline_controller_clone_timeline

        """
        pass

    def test_timeline_controller_get_timeline_status(self):
        """Test case for timeline_controller_get_timeline_status

        """
        pass

    def test_update_one_base_dataset_controller_dataset(self):
        """Test case for update_one_base_dataset_controller_dataset

        Update one Dataset  # noqa: E501
        """
        pass

    def test_update_one_base_environment_controller_environment(self):
        """Test case for update_one_base_environment_controller_environment

        Update one Environment  # noqa: E501
        """
        pass

    def test_update_one_base_intervention_controller_intervention(self):
        """Test case for update_one_base_intervention_controller_intervention

        Update one Intervention  # noqa: E501
        """
        pass

    def test_update_one_base_model_controller_model(self):
        """Test case for update_one_base_model_controller_model

        Update one Model  # noqa: E501
        """
        pass

    def test_update_one_base_model_dataset_controller_model_dataset(self):
        """Test case for update_one_base_model_dataset_controller_model_dataset

        Update one ModelDataset  # noqa: E501
        """
        pass

    def test_update_one_base_model_endpoint_controller_model_endpoint(self):
        """Test case for update_one_base_model_endpoint_controller_model_endpoint

        Update one ModelEndpoint  # noqa: E501
        """
        pass

    def test_update_one_base_model_job_controller_model_job(self):
        """Test case for update_one_base_model_job_controller_model_job

        Update one ModelJob  # noqa: E501
        """
        pass

    def test_update_one_base_organization_setting_controller_organization_setting(self):
        """Test case for update_one_base_organization_setting_controller_organization_setting

        Update one OrganizationSetting  # noqa: E501
        """
        pass

    def test_update_one_base_organizations_controller_organization(self):
        """Test case for update_one_base_organizations_controller_organization

        Update one Organization  # noqa: E501
        """
        pass

    def test_update_one_base_project_controller_project(self):
        """Test case for update_one_base_project_controller_project

        Update one Project  # noqa: E501
        """
        pass

    def test_update_one_base_project_member_controller_project_member(self):
        """Test case for update_one_base_project_member_controller_project_member

        Update one ProjectMember  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_code_filter_controller_timeline_code_filter(self):
        """Test case for update_one_base_timeline_code_filter_controller_timeline_code_filter

        Update one TimelineCodeFilter  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_controller_timeline(self):
        """Test case for update_one_base_timeline_controller_timeline

        Update one Timeline  # noqa: E501
        """
        pass

    def test_update_one_base_timeline_feature_filter_controller_timeline_feature_filter(self):
        """Test case for update_one_base_timeline_feature_filter_controller_timeline_feature_filter

        Update one TimelineFeatureFilter  # noqa: E501
        """
        pass

    def test_update_one_base_user_favorite_controller_user_favorite(self):
        """Test case for update_one_base_user_favorite_controller_user_favorite

        Update one UserFavorite  # noqa: E501
        """
        pass

    def test_user_management_controller_assign_user_permissions(self):
        """Test case for user_management_controller_assign_user_permissions

        """
        pass

    def test_user_management_controller_assign_user_roles(self):
        """Test case for user_management_controller_assign_user_roles

        """
        pass

    def test_user_management_controller_get_my_user(self):
        """Test case for user_management_controller_get_my_user

        """
        pass

    def test_user_management_controller_get_my_user_api_key(self):
        """Test case for user_management_controller_get_my_user_api_key

        """
        pass

    def test_user_management_controller_get_roles(self):
        """Test case for user_management_controller_get_roles

        """
        pass

    def test_user_management_controller_get_user(self):
        """Test case for user_management_controller_get_user

        """
        pass

    def test_user_management_controller_get_users(self):
        """Test case for user_management_controller_get_users

        """
        pass

    def test_user_management_controller_invite_user(self):
        """Test case for user_management_controller_invite_user

        """
        pass

    def test_user_management_controller_remove_user_permission(self):
        """Test case for user_management_controller_remove_user_permission

        """
        pass

    def test_user_management_controller_remove_user_roles(self):
        """Test case for user_management_controller_remove_user_roles

        """
        pass

    def test_user_management_controller_request_password_reset(self):
        """Test case for user_management_controller_request_password_reset

        """
        pass

    def test_user_management_controller_update_my_user(self):
        """Test case for user_management_controller_update_my_user

        """
        pass

    def test_user_management_controller_update_user(self):
        """Test case for user_management_controller_update_user

        """
        pass

    def test_user_management_controller_update_user_metadata(self):
        """Test case for user_management_controller_update_user_metadata

        """
        pass


if __name__ == '__main__':
    unittest.main()
